@@ -1,5 +1,5 @@
 # PyCO2SYS: marine carbonate system calculations in Python.
-# Copyright (C) 2020--2021  Matthew P. Humphreys et al.  (GNU GPLv3)
+# Copyright (C) 2020--2022  Matthew P. Humphreys et al.  (GNU GPLv3)
 """Estimate stoichiometric equilibrium constants at atmospheric pressure."""
 
 from autograd import numpy as np
@@ -16,7 +16,7 @@ def kCO2_W74(TempK, Sal):
         -60.2409
         + 93.4517 / TempK100
         + 23.3585 * np.log(TempK100)
-        + Sal * (0.023517 - 0.023656 * TempK100 + 0.0047036 * TempK100 ** 2)
+        + Sal * (0.023517 - 0.023656 * TempK100 + 0.0047036 * TempK100**2)
     )
     return np.exp(lnK0)
 
@@ -31,7 +31,7 @@ def kHSO4_FREE_D90a(TempK, Sal):
     # Output KS is on the free pH scale in mol/kg-sw.
     # This is from eqs 22 and 23 on p. 123, and Table 4 on p 121:
     logTempK = np.log(TempK)
-    IonS = salts.ionstr_DOE94(Sal)
+    IonS = salts.ionic_strength_DOE94(Sal)
     lnKSO4 = (
         -4276.1 / TempK
         + 141.328
@@ -39,7 +39,7 @@ def kHSO4_FREE_D90a(TempK, Sal):
         + (-13856 / TempK + 324.57 - 47.986 * logTempK) * np.sqrt(IonS)
         + (35474 / TempK - 771.54 + 114.723 * logTempK) * IonS
         + (-2698 / TempK) * np.sqrt(IonS) * IonS
-        + (1776 / TempK) * IonS ** 2
+        + (1776 / TempK) * IonS**2
     )
     return np.exp(lnKSO4) * (1 - 0.001005 * Sal)
 
@@ -60,9 +60,9 @@ def kHSO4_FREE_KRCB77(TempK, Sal):
     # The rms error is .0021 in pKS, or about .5% in KS.
     # This is equation 20 on p. 33:
     # Output KS is on the free pH scale in mol/kg-sw.
-    IonS = salts.ionstr_DOE94(Sal)
+    IonS = salts.ionic_strength_DOE94(Sal)
     pKSO4 = 647.59 / TempK - 6.3451 + 0.019085 * TempK - 0.5208 * np.sqrt(IonS)
-    return 10.0 ** -pKSO4 * (1 - 0.001005 * Sal)
+    return 10.0**-pKSO4 * (1 - 0.001005 * Sal)
 
 
 def kHSO4_FREE_WM13(TempK, Sal):
@@ -70,7 +70,7 @@ def kHSO4_FREE_WM13(TempK, Sal):
     logKS0 = (
         562.69486
         - 102.5154 * np.log(TempK)
-        - 0.0001117033 * TempK ** 2
+        - 0.0001117033 * TempK**2
         + 0.2477538 * TempK
         - 13273.76 / TempK
     )
@@ -79,12 +79,12 @@ def kHSO4_FREE_WM13(TempK, Sal):
             4.24666
             - 0.152671 * TempK
             + 0.0267059 * TempK * np.log(TempK)
-            - 0.000042128 * TempK ** 2
+            - 0.000042128 * TempK**2
         )
-        * Sal ** 0.5
+        * Sal**0.5
         + (0.2542181 - 0.00509534 * TempK + 0.00071589 * TempK * np.log(TempK)) * Sal
-        + (-0.00291179 + 0.0000209968 * TempK) * Sal ** 1.5
-        + -0.0000403724 * Sal ** 2
+        + (-0.00291179 + 0.0000209968 * TempK) * Sal**1.5
+        + -0.0000403724 * Sal**2
     )
     kSO4 = (1 - 0.001005 * Sal) * 10.0 ** (logKSK0 + logKS0)
     return kSO4
@@ -95,8 +95,8 @@ def kHF_FREE_DR79(TempK, Sal):
     # === CO2SYS.m comments: =======
     # Dickson, A. G. and Riley, J. P., Marine Chemistry 7:89-99, 1979:
     # this is on the free pH scale in mol/kg-sw
-    IonS = salts.ionstr_DOE94(Sal)
-    lnKF = 1590.2 / TempK - 12.641 + 1.525 * IonS ** 0.5
+    IonS = salts.ionic_strength_DOE94(Sal)
+    lnKF = 1590.2 / TempK - 12.641 + 1.525 * IonS**0.5
     return np.exp(lnKF) * (1 - 0.001005 * Sal)
 
 
@@ -110,7 +110,7 @@ def kHF_FREE_PF87(TempK, Sal):
     # Nonetheless, P&F87 might actually be better than the fit of D&R79 above,
     # which is based on only three Salinities: [0 26.7 34.6]
     # Output is on the free pH scale in mol/kg-SW.
-    lnKF = 874 / TempK - 9.68 + 0.111 * Sal ** 0.5
+    lnKF = 874 / TempK - 9.68 + 0.111 * Sal**0.5
     return np.exp(lnKF)
 
 
@@ -123,7 +123,7 @@ def kBOH3_NBS_LTB69(TempK, Sal):
     # logKB is on NBS pH scale
     TempC = TempK - 273.15
     logKB = -9.26 + 0.00886 * Sal + 0.01 * TempC
-    return 10.0 ** logKB
+    return 10.0**logKB
 
 
 def kBOH3_TOT_D90b(TempK, Sal):
@@ -137,7 +137,7 @@ def kBOH3_TOT_D90b(TempK, Sal):
         - 2890.53 * sqrSal
         - 77.942 * Sal
         + 1.728 * sqrSal * Sal
-        - 0.0996 * Sal ** 2
+        - 0.0996 * Sal**2
     )
     lnKB = (
         lnKBtop / TempK
@@ -246,14 +246,14 @@ def kSi_SWS_YM95(TempK, Sal):
     # Yao and Millero, Aquatic Geochemistry 1:53-88, 1995
     # KSi was given on the SWS pH scale in mol/kg-H2O, but is converted here
     # to mol/kg-sw.
-    IonS = salts.ionstr_DOE94(Sal)
+    IonS = salts.ionic_strength_DOE94(Sal)
     lnKSi = (
         -8904.2 / TempK
         + 117.4
         - 19.334 * np.log(TempK)
         + (-458.79 / TempK + 3.5913) * np.sqrt(IonS)
         + (188.74 / TempK - 1.5998) * IonS
-        + (-12.1652 / TempK + 0.07871) * IonS ** 2
+        + (-12.1652 / TempK + 0.07871) * IonS**2
     )
     return np.exp(lnKSi) * (1 - 0.001005 * Sal)
 
@@ -308,11 +308,11 @@ def kH2CO3_SWS_GP89(TempK, Sal):
     # The 2s precision in pK1 is .011, or 2.5% in K1.
     # The 2s precision in pK2 is .02, or 4.5% in K2.
     # This is in Table 5 on p. 1652 and what they use in the abstract:
-    pK1 = 812.27 / TempK + 3.356 - 0.00171 * Sal * np.log(TempK) + 0.000091 * Sal ** 2
-    K1 = 10.0 ** -pK1  # this is on the SWS pH scale in mol/kg-SW
+    pK1 = 812.27 / TempK + 3.356 - 0.00171 * Sal * np.log(TempK) + 0.000091 * Sal**2
+    K1 = 10.0**-pK1  # this is on the SWS pH scale in mol/kg-SW
     # This is in Table 5 on p. 1652 and what they use in the abstract:
-    pK2 = 1450.87 / TempK + 4.604 - 0.00385 * Sal * np.log(TempK) + 0.000182 * Sal ** 2
-    K2 = 10.0 ** -pK2  # this is on the SWS pH scale in mol/kg-SW
+    pK2 = 1450.87 / TempK + 4.604 - 0.00385 * Sal * np.log(TempK) + 0.000182 * Sal**2
+    K2 = 10.0**-pK2  # this is on the SWS pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -333,17 +333,17 @@ def kH2CO3_SWS_H73_DM87(TempK, Sal):
     # The 2s precision in pK1 is .013, or 3% in K1.
     # The 2s precision in pK2 is .017, or 4.1% in K2.
     # This is from Table 4 on p. 1739.
-    pK1 = 851.4 / TempK + 3.237 - 0.0106 * Sal + 0.000105 * Sal ** 2
-    K1 = 10.0 ** -pK1  # this is on the SWS pH scale in mol/kg-SW
+    pK1 = 851.4 / TempK + 3.237 - 0.0106 * Sal + 0.000105 * Sal**2
+    K1 = 10.0**-pK1  # this is on the SWS pH scale in mol/kg-SW
     # This is from Table 4 on p. 1739.
     pK2 = (
         -3885.4 / TempK
         + 125.844
         - 18.141 * np.log(TempK)
         - 0.0192 * Sal
-        + 0.000132 * Sal ** 2
+        + 0.000132 * Sal**2
     )
-    K2 = 10.0 ** -pK2  # this is on the SWS pH scale in mol/kg-SW
+    K2 = 10.0**-pK2  # this is on the SWS pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -365,12 +365,12 @@ def kH2CO3_SWS_MCHP73_DM87(TempK, Sal):
         - 62.008
         + 9.7944 * np.log(TempK)
         - 0.0118 * Sal
-        + 0.000116 * Sal ** 2
+        + 0.000116 * Sal**2
     )
-    K1 = 10.0 ** -pK1  # this is on the SWS pH scale in mol/kg-SW
+    K1 = 10.0**-pK1  # this is on the SWS pH scale in mol/kg-SW
     # This is in Table 4 on p. 1739.
-    pK2 = 1394.7 / TempK + 4.777 - 0.0184 * Sal + 0.000118 * Sal ** 2
-    K2 = 10.0 ** -pK2  # this is on the SWS pH scale in mol/kg-SW
+    pK2 = 1394.7 / TempK + 4.777 - 0.0184 * Sal + 0.000118 * Sal**2
+    K2 = 10.0**-pK2  # this is on the SWS pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -392,11 +392,11 @@ def kH2CO3_SWS_HM_DM87(TempK, Sal):
     # The 2s precision in pK2 is .026, or 6% in K2.
     # Valid for salinity 20-40.
     # This is in Table 5 on p. 1740.
-    pK1 = 845 / TempK + 3.248 - 0.0098 * Sal + 0.000087 * Sal ** 2
-    K1 = 10.0 ** -pK1  # this is on the SWS pH scale in mol/kg-SW
+    pK1 = 845 / TempK + 3.248 - 0.0098 * Sal + 0.000087 * Sal**2
+    K1 = 10.0**-pK1  # this is on the SWS pH scale in mol/kg-SW
     # This is in Table 5 on p. 1740.
-    pK2 = 1377.3 / TempK + 4.824 - 0.0185 * Sal + 0.000122 * Sal ** 2
-    K2 = 10.0 ** -pK2  # this is on the SWS pH scale in mol/kg-SW
+    pK2 = 1377.3 / TempK + 4.824 - 0.0185 * Sal + 0.000122 * Sal**2
+    K2 = 10.0**-pK2  # this is on the SWS pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -414,9 +414,9 @@ def kH2CO3_NBS_MCHP73(TempK, Sal):
         + 0.031334 * TempK
         + 3235.76 / TempK
         + 1.3e-5 * Sal * TempK
-        - 0.1032 * Sal ** 0.5
+        - 0.1032 * Sal**0.5
     )
-    K1 = 10.0 ** -pK1  # this is on the NBS scale
+    K1 = 10.0**-pK1  # this is on the NBS scale
     pK2 = (
         5371.9645
         + 1.671221 * TempK
@@ -428,7 +428,7 @@ def kH2CO3_NBS_MCHP73(TempK, Sal):
         - 5617.11 * np.log10(Sal) / TempK
         + 2.136 * Sal / TempK
     )  # pK2 is not defined for Sal=0, since log10(0)=-inf
-    K2 = 10.0 ** -pK2  # this is on the NBS scale
+    K2 = 10.0**-pK2  # this is on the NBS scale
     return K1, K2
 
 
@@ -473,19 +473,19 @@ def kH2CO3_NBS_CW98(TempK, Sal):
         3404.71 / TempK
         + 0.032786 * TempK
         - 14.8435
-        - 0.071692 * F1 * Sal ** 0.5
+        - 0.071692 * F1 * Sal**0.5
         + 0.0021487 * Sal
     )
-    K1 = 10.0 ** -pK1  # this is on the NBS scale
+    K1 = 10.0**-pK1  # this is on the NBS scale
     F2 = -129.24 / TempK + 1.4381
     pK2 = (
         2902.39 / TempK
         + 0.02379 * TempK
         - 6.4980
-        - 0.3191 * F2 * Sal ** 0.5
+        - 0.3191 * F2 * Sal**0.5
         + 0.0198 * Sal
     )
-    K2 = 10.0 ** -pK2  # this is on the NBS scale
+    K2 = 10.0**-pK2  # this is on the NBS scale
     return K1, K2
 
 
@@ -502,17 +502,17 @@ def kH2CO3_TOT_LDK00(TempK, Sal):
         - 61.2172
         + 9.6777 * np.log(TempK)
         - 0.011555 * Sal
-        + 0.0001152 * Sal ** 2
+        + 0.0001152 * Sal**2
     )
-    K1 = 10.0 ** -pK1  # this is on the Total pH scale in mol/kg-SW
+    K1 = 10.0**-pK1  # this is on the Total pH scale in mol/kg-SW
     pK2 = (
         471.78 / TempK
         + 25.929
         - 3.16967 * np.log(TempK)
         - 0.01781 * Sal
-        + 0.0001122 * Sal ** 2
+        + 0.0001122 * Sal**2
     )
-    K2 = 10.0 ** -pK2  # this is on the Total pH scale in mol/kg-SW
+    K2 = 10.0**-pK2  # this is on the Total pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -527,21 +527,21 @@ def kH2CO3_SWS_MM02(TempK, Sal):
     pK1 = (
         -43.6977
         - 0.0129037 * Sal
-        + 1.364e-4 * Sal ** 2
+        + 1.364e-4 * Sal**2
         + 2885.378 / TempK
         + 7.045159 * np.log(TempK)
     )
     pK2 = (
         -452.0940
         + 13.142162 * Sal
-        - 8.101e-4 * Sal ** 2
+        - 8.101e-4 * Sal**2
         + 21263.61 / TempK
         + 68.483143 * np.log(TempK)
-        + (-581.4428 * Sal + 0.259601 * Sal ** 2) / TempK
+        + (-581.4428 * Sal + 0.259601 * Sal**2) / TempK
         - 1.967035 * Sal * np.log(TempK)
     )
-    K1 = 10.0 ** -pK1  # this is on the SWS pH scale in mol/kg-SW
-    K2 = 10.0 ** -pK2  # this is on the SWS pH scale in mol/kg-SW
+    K1 = 10.0**-pK1  # this is on the SWS pH scale in mol/kg-SW
+    K2 = 10.0**-pK2  # this is on the SWS pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -554,10 +554,10 @@ def kH2CO3_SWS_MPL02(TempK, Sal):
     # sigma for pK2 is reported to be 0.008
     # This is from page 1715
     TempC = TempK - 273.15
-    pK1 = 6.359 - 0.00664 * Sal - 0.01322 * TempC + 4.989e-5 * TempC ** 2
-    pK2 = 9.867 - 0.01314 * Sal - 0.01904 * TempC + 2.448e-5 * TempC ** 2
-    K1 = 10.0 ** -pK1  # this is on the SWS pH scale in mol/kg-SW
-    K2 = 10.0 ** -pK2  # this is on the SWS pH scale in mol/kg-SW
+    pK1 = 6.359 - 0.00664 * Sal - 0.01322 * TempC + 4.989e-5 * TempC**2
+    pK2 = 9.867 - 0.01314 * Sal - 0.01904 * TempC + 2.448e-5 * TempC**2
+    K1 = 10.0**-pK1  # this is on the SWS pH scale in mol/kg-SW
+    K2 = 10.0**-pK2  # this is on the SWS pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -570,15 +570,15 @@ def kH2CO3_SWS_MGH06(TempK, Sal):
     # S=1 to 50, T=0 to 50. On seawater scale (SWS). From titrations in Gulf
     # Stream seawater.
     pK1_0 = -126.34048 + 6320.813 / TempK + 19.568224 * np.log(TempK)
-    A_1 = 13.4191 * Sal ** 0.5 + 0.0331 * Sal - 5.33e-5 * Sal ** 2
-    B_1 = -530.123 * Sal ** 0.5 - 6.103 * Sal
-    C_1 = -2.06950 * Sal ** 0.5
+    A_1 = 13.4191 * Sal**0.5 + 0.0331 * Sal - 5.33e-5 * Sal**2
+    B_1 = -530.123 * Sal**0.5 - 6.103 * Sal
+    C_1 = -2.06950 * Sal**0.5
     pK1 = A_1 + B_1 / TempK + C_1 * np.log(TempK) + pK1_0  # pK1 sigma = 0.0054
     K1 = 10.0 ** -(pK1)
     pK2_0 = -90.18333 + 5143.692 / TempK + 14.613358 * np.log(TempK)
-    A_2 = 21.0894 * Sal ** 0.5 + 0.1248 * Sal - 3.687e-4 * Sal ** 2
-    B_2 = -772.483 * Sal ** 0.5 - 20.051 * Sal
-    C_2 = -3.3336 * Sal ** 0.5
+    A_2 = 21.0894 * Sal**0.5 + 0.1248 * Sal - 3.687e-4 * Sal**2
+    B_2 = -772.483 * Sal**0.5 - 20.051 * Sal
+    C_2 = -3.3336 * Sal**0.5
     pK2 = A_2 + B_2 / TempK + C_2 * np.log(TempK) + pK2_0  # pK2 sigma = 0.011
     K2 = 10.0 ** -(pK2)
     return K1, K2
@@ -596,19 +596,19 @@ def kH2CO3_SWS_M10(TempK, Sal):
     # This is from page 141
     pK10 = -126.34048 + 6320.813 / TempK + 19.568224 * np.log(TempK)
     # This is from their table 2, page 140.
-    A1 = 13.4038 * Sal ** 0.5 + 0.03206 * Sal - 5.242e-5 * Sal ** 2
-    B1 = -530.659 * Sal ** 0.5 - 5.8210 * Sal
-    C1 = -2.0664 * Sal ** 0.5
+    A1 = 13.4038 * Sal**0.5 + 0.03206 * Sal - 5.242e-5 * Sal**2
+    B1 = -530.659 * Sal**0.5 - 5.8210 * Sal
+    C1 = -2.0664 * Sal**0.5
     pK1 = pK10 + A1 + B1 / TempK + C1 * np.log(TempK)
-    K1 = 10.0 ** -pK1
+    K1 = 10.0**-pK1
     # This is from page 141
     pK20 = -90.18333 + 5143.692 / TempK + 14.613358 * np.log(TempK)
     # This is from their table 3, page 140.
-    A2 = 21.3728 * Sal ** 0.5 + 0.1218 * Sal - 3.688e-4 * Sal ** 2
-    B2 = -788.289 * Sal ** 0.5 - 19.189 * Sal
-    C2 = -3.374 * Sal ** 0.5
+    A2 = 21.3728 * Sal**0.5 + 0.1218 * Sal - 3.688e-4 * Sal**2
+    B2 = -788.289 * Sal**0.5 - 19.189 * Sal
+    C2 = -3.374 * Sal**0.5
     pK2 = pK20 + A2 + B2 / TempK + C2 * np.log(TempK)
-    K2 = 10.0 ** -pK2
+    K2 = 10.0**-pK2
     return K1, K2
 
 
@@ -629,16 +629,16 @@ def kH2CO3_SWS_WMW14(TempK, Sal):
     # (WhichKs==14)
     # Constants for K's on the SWS;
     pK10, pK20 = _kH2CO3_WMW14(TempK)
-    A1 = 13.409160 * Sal ** 0.5 + 0.031646 * Sal - 5.1895e-5 * Sal ** 2
-    B1 = -531.3642 * Sal ** 0.5 - 5.713 * Sal
-    C1 = -2.0669166 * Sal ** 0.5
+    A1 = 13.409160 * Sal**0.5 + 0.031646 * Sal - 5.1895e-5 * Sal**2
+    B1 = -531.3642 * Sal**0.5 - 5.713 * Sal
+    C1 = -2.0669166 * Sal**0.5
     pK1 = pK10 + A1 + B1 / TempK + C1 * np.log(TempK)
-    K1 = 10.0 ** -pK1
-    A2 = 21.225890 * Sal ** 0.5 + 0.12450870 * Sal - 3.7243e-4 * Sal ** 2
-    B2 = -779.3444 * Sal ** 0.5 - 19.91739 * Sal
-    C2 = -3.3534679 * Sal ** 0.5
+    K1 = 10.0**-pK1
+    A2 = 21.225890 * Sal**0.5 + 0.12450870 * Sal - 3.7243e-4 * Sal**2
+    B2 = -779.3444 * Sal**0.5 - 19.91739 * Sal
+    C2 = -3.3534679 * Sal**0.5
     pK2 = pK20 + A2 + B2 / TempK + C2 * np.log(TempK)
-    K2 = 10.0 ** -pK2
+    K2 = 10.0**-pK2
     return K1, K2
 
 
@@ -646,16 +646,16 @@ def k_H2CO3_TOT_WMW14(TempK, Sal):
     """Carbonic acid dissociation constants, Total scale, following WM13/WMW14."""
     # Coefficients from the corrigendum document [WMW14]
     pK10, pK20 = _kH2CO3_WMW14(TempK)
-    A1 = 13.568513 * Sal ** 0.5 + 0.031645 * Sal - 5.3834e-5 * Sal ** 2
-    B1 = -539.2304 * Sal ** 0.5 - 5.635 * Sal
-    C1 = -2.0901396 * Sal ** 0.5
+    A1 = 13.568513 * Sal**0.5 + 0.031645 * Sal - 5.3834e-5 * Sal**2
+    B1 = -539.2304 * Sal**0.5 - 5.635 * Sal
+    C1 = -2.0901396 * Sal**0.5
     pK1 = pK10 + A1 + B1 / TempK + C1 * np.log(TempK)
-    K1 = 10.0 ** -pK1
-    A2 = 21.389248 * Sal ** 0.5 + 0.12452358 * Sal - 3.7447e-4 * Sal ** 2
-    B2 = -787.3736 * Sal ** 0.5 - 19.84233 * Sal
-    C2 = -3.3773006 * Sal ** 0.5
+    K1 = 10.0**-pK1
+    A2 = 21.389248 * Sal**0.5 + 0.12452358 * Sal - 3.7447e-4 * Sal**2
+    B2 = -787.3736 * Sal**0.5 - 19.84233 * Sal
+    C2 = -3.3773006 * Sal**0.5
     pK2 = pK20 + A2 + B2 / TempK + C2 * np.log(TempK)
-    K2 = 10.0 ** -pK2
+    K2 = 10.0**-pK2
     return K1, K2
 
 
@@ -663,16 +663,16 @@ def k_H2CO3_FREE_WMW14(TempK, Sal):
     """Carbonic acid dissociation constants, Free scale, following WM13/WMW14."""
     # Coefficients from the corrigendum document [WMW14]
     pK10, pK20 = _kH2CO3_WMW14(TempK)
-    A1 = 5.592953 * Sal ** 0.5 + 0.028845 * Sal - 6.388e-5 * Sal ** 2
-    B1 = -225.7489 * Sal ** 0.5 - 4.761 * Sal
-    C1 = -0.8715109 * Sal ** 0.5
+    A1 = 5.592953 * Sal**0.5 + 0.028845 * Sal - 6.388e-5 * Sal**2
+    B1 = -225.7489 * Sal**0.5 - 4.761 * Sal
+    C1 = -0.8715109 * Sal**0.5
     pK1 = pK10 + A1 + B1 / TempK + C1 * np.log(TempK)
-    K1 = 10.0 ** -pK1
-    A2 = 13.396949 * Sal ** 0.5 + 0.12193009 * Sal - 3.8362e-4 * Sal ** 2
-    B2 = -472.8633 * Sal ** 0.5 - 19.03634 * Sal
-    C2 = -2.1563270 * Sal ** 0.5
+    K1 = 10.0**-pK1
+    A2 = 13.396949 * Sal**0.5 + 0.12193009 * Sal - 3.8362e-4 * Sal**2
+    B2 = -472.8633 * Sal**0.5 - 19.03634 * Sal
+    C2 = -2.1563270 * Sal**0.5
     pK2 = pK20 + A2 + B2 / TempK + C2 * np.log(TempK)
-    K2 = 10.0 ** -pK2
+    K2 = 10.0**-pK2
     return K1, K2
 
 
@@ -684,17 +684,17 @@ def kH2CO3_TOT_SLH20(TempK, Sal):
         - 172.4493  # ±26.131
         + 26.32996 * np.log(TempK)  # ±3.9161
         - 0.011555 * Sal
-        + 0.0001152 * Sal ** 2
+        + 0.0001152 * Sal**2
     )
-    K1 = 10.0 ** -pK1  # this is on the Total pH scale in mol/kg-SW
+    K1 = 10.0**-pK1  # this is on the Total pH scale in mol/kg-SW
     pK2 = (
         4226.23 / TempK  # ±1050.8
         - 59.4636  # ±24.016
         + 9.60817 * np.log(TempK)  # ±3.5966
         - 0.01781 * Sal
-        + 0.0001122 * Sal ** 2
+        + 0.0001122 * Sal**2
     )
-    K2 = 10.0 ** -pK2  # this is on the Total pH scale in mol/kg-SW
+    K2 = 10.0**-pK2  # this is on the Total pH scale in mol/kg-SW
     return K1, K2
 
 
@@ -709,10 +709,10 @@ def kH2CO3_TOT_SB21(TempK, Sal):
         - 16.45817 * np.log(TempK)
         + 0.04523 * Sal
         - 0.615 * np.sqrt(Sal)
-        - 0.0002799 * Sal ** 2
+        - 0.0002799 * Sal**2
         + 4.969 * Sal / TempK
     )
-    K2 = 10.0 ** -pK2
+    K2 = 10.0**-pK2
     return K1, K2
 
 
@@ -756,20 +756,20 @@ def kNH3_TOT_CW95(TempK, Sal):
     # Geochimica et Cosmochimica Acta, Vol. 59, No. 12. pp. 2403-2421
     # eq (18)  Total scale   t=[-2 to 40 oC]  S=[0 to 40 ppt]   pK=+-0.00015
     PKNH3expCW = 9.244605 - 2729.33 * (1 / 298.15 - 1 / TempK)
-    PKNH3expCW += (0.04203362 - 11.24742 / TempK) * Sal ** 0.25
+    PKNH3expCW += (0.04203362 - 11.24742 / TempK) * Sal**0.25
     PKNH3expCW += (
-        -13.6416 + 1.176949 * TempK ** 0.5 - 0.02860785 * TempK + 545.4834 / TempK
-    ) * Sal ** 0.5
+        -13.6416 + 1.176949 * TempK**0.5 - 0.02860785 * TempK + 545.4834 / TempK
+    ) * Sal**0.5
     PKNH3expCW += (
         -0.1462507
-        + 0.0090226468 * TempK ** 0.5
+        + 0.0090226468 * TempK**0.5
         - 0.0001471361 * TempK
         + 10.5425 / TempK
-    ) * Sal ** 1.5
+    ) * Sal**1.5
     PKNH3expCW += (
-        0.004669309 - 0.0001691742 * TempK ** 0.5 - 0.5677934 / TempK
-    ) * Sal ** 2
-    PKNH3expCW += (-2.354039e-05 + 0.009698623 / TempK) * Sal ** 2.5
-    KNH3 = 10.0 ** -PKNH3expCW  # this is on the total pH scale in mol/kg-H2O
+        0.004669309 - 0.0001691742 * TempK**0.5 - 0.5677934 / TempK
+    ) * Sal**2
+    PKNH3expCW += (-2.354039e-05 + 0.009698623 / TempK) * Sal**2.5
+    KNH3 = 10.0**-PKNH3expCW  # this is on the total pH scale in mol/kg-H2O
     KNH3 = KNH3 * (1 - 0.001005 * Sal)  # convert to mol/kg-SW
     return KNH3
