@@ -1,5 +1,5 @@
 # PyCO2SYS: marine carbonate system calculations in Python.
-# Copyright (C) 2020--2021  Matthew P. Humphreys et al.  (GNU GPLv3)
+# Copyright (C) 2020--2022  Matthew P. Humphreys et al.  (GNU GPLv3)
 """Calculate saturation states of soluble solids."""
 
 from autograd import numpy as np
@@ -22,9 +22,9 @@ def k_calcite_M83(TempK, Sal, Pbar, RGas):
     logKCa = logKCa + (-0.77712 + 0.0028426 * TempK + 178.34 / TempK) * np.sqrt(Sal)
     logKCa = logKCa - 0.07711 * Sal + 0.0041249 * np.sqrt(Sal) * Sal
     # sd fit = .01 (for Sal part, not part independent of Sal)
-    KCa = 10.0 ** logKCa  # this is in (mol/kg-SW)^2 at zero pressure
+    KCa = 10.0**logKCa  # this is in (mol/kg-SW)^2 at zero pressure
     # Add pressure correction for calcite [I75, M79]
-    TempC = convert.TempK2C(TempK)
+    TempC = convert.kelvin_to_celsius(TempK)
     deltaVKCa, KappaKCa = _deltaKappaCalcite_I75(TempC)
     lnKCafac = (-deltaVKCa + 0.5 * KappaKCa * Pbar) * Pbar / (RGas * TempK)
     KCa = KCa * np.exp(lnKCafac)
@@ -38,9 +38,9 @@ def k_aragonite_M83(TempK, Sal, Pbar, RGas):
     logKAr = logKAr + (-0.068393 + 0.0017276 * TempK + 88.135 / TempK) * np.sqrt(Sal)
     logKAr = logKAr - 0.10018 * Sal + 0.0059415 * np.sqrt(Sal) * Sal
     # sd fit = .009 (for Sal part, not part independent of Sal)
-    KAr = 10.0 ** logKAr  # this is in (mol/kg-SW)^2
+    KAr = 10.0**logKAr  # this is in (mol/kg-SW)^2
     # Add pressure correction for aragonite [M79]:
-    TempC = convert.TempK2C(TempK)
+    TempC = convert.kelvin_to_celsius(TempK)
     deltaVKCa, KappaKCa = _deltaKappaCalcite_I75(TempC)
     # Same as Millero, GCA 1995 except for typos (-.5304, -.3692,
     #   and 10^3 for Kappa factor)
@@ -60,7 +60,7 @@ def k_calcite_P0_I75(TempK, Sal):
         -34.452
         - 39.866 * Sal ** (1 / 3)
         + 110.21 * np.log10(Sal)
-        - 0.0000075752 * TempK ** 2
+        - 0.0000075752 * TempK**2
     )
 
 
@@ -84,7 +84,7 @@ def k_calcite_I75(TempK, Sal, Pbar, RGas):
     # The fits appears to be new in the GEOSECS report.
     # I can't find them anywhere else.
     # ==============================
-    TempC = convert.TempK2C(TempK)
+    TempC = convert.kelvin_to_celsius(TempK)
     KCa = KCa * np.exp((36 - 0.2 * TempC) * Pbar / (RGas * TempK))
     return KCa
 
@@ -108,7 +108,7 @@ def k_aragonite_GEOSECS(TempK, Sal, Pbar, RGas):
     # but their paper is not even on this topic).
     # The fits appears to be new in the GEOSECS report.
     # I can't find them anywhere else.
-    TempC = convert.TempK2C(TempK)
+    TempC = convert.kelvin_to_celsius(TempK)
     KAr = KAr * np.exp((33.3 - 0.22 * TempC) * Pbar / (RGas * TempK))
     return KAr
 
@@ -126,3 +126,13 @@ def CaCO3(CARB, totals, Ks):
     OmegaCa = CARB * totals["TCa"] / Ks["KCa"]
     OmegaAr = CARB * totals["TCa"] / Ks["KAr"]
     return OmegaCa, OmegaAr
+
+
+def CARB_from_OC(OC, totals, Ks):
+    """Calculate [CO3] given saturation state w.r.t. calcite."""
+    return OC * Ks["KCa"] / totals["TCa"]
+
+
+def CARB_from_OA(OA, totals, Ks):
+    """Calculate [CO3] given saturation state w.r.t. aragonite."""
+    return OA * Ks["KAr"] / totals["TCa"]
