@@ -2,7 +2,7 @@ import pandas as pd, numpy as np
 import PyCO2SYS as pyco2
 
 # Import MATLAB results and recalculate with PyCO2SYS
-matlab = pd.read_csv("manuscript/results/compare_equilibrium_constants_v3_2_0.csv")
+matlab = pd.read_csv("manuscript/results/compare_equilibrium_constants_v3_1_1.csv")
 python = pd.DataFrame(
     pyco2.sys(
         matlab.PAR1.values,
@@ -24,7 +24,7 @@ python = pd.DataFrame(
         total_silicate=matlab.SI.values,
         total_ammonia=matlab.TNH4.values,
         total_sulfide=matlab.TH2S.values,
-        buffers_mode="none",
+        opt_buffers_mode=0,
     )
 )
 
